@@ -8,9 +8,19 @@
 
 #rm ./*.log
 
+NS3VER=3.8
+NS3_DIR=ns-$NS3VER
+PYBINDGENV_DIR=pybindgen-0.14.1
+REFTRACE_DIR=ns-3.8-ref-traces
+NSC_DIR=nsc-0.5.1
+
+
+
+cd debian
+
 rm ../.config
 
-cd ../ns-3.7.1
+cd ../$NS3_DIR
 
 
 make clean -C ./doc/manual
@@ -27,13 +37,16 @@ rm -rf ./build
 find . -name '*.pyc' -exec rm {} \;
 find . -name '.waf-*' -exec rm -rf {} \;
 
-cd ../pybindgen-0.12.0.710
+cd ../$PYBINDGENV_DIR
 find . -name '*.pyc' -exec rm {} \;
 find . -name '.waf-*' -exec rm -rf {} \;
 
-cd ../nsc-0.5.1
+cd ../$NSC_DIR
 rm ./config.log
 find . -name '*.pyc' -exec rm {} \;
 find . -name '.waf-*' -exec rm -rf {} \;
 rm -rf .sconf_temp
 rm .sconsign.dblite
+
+
+exit 0
